@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2017 ECMWF.
+ * Copyright 2005-2018 ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -88,7 +88,7 @@ int main(int argc,char* argv[])
             {
                 /* not array */
                 vlen=MAX_VAL_LEN;
-                bzero(value,vlen);
+                memset(value, 0, vlen);
                 codes_get_string(h,name,value,&vlen);
                 printf("%s\n",value);
             }
