@@ -1,5 +1,5 @@
 #!/bin/sh
-# Copyright 2005-2016 ECMWF.
+# Copyright 2005-2018 ECMWF.
 #
 # This software is licensed under the terms of the Apache Licence Version 2.0
 # which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -12,11 +12,11 @@
 TEMP=c_grib_copy_message.grib
 
 INPUT=${data_dir}/reduced_gaussian_pressure_level.grib1
-${examples_dir}c_grib_copy_message ${INPUT} ${TEMP}  > /dev/null
-${tools_dir}grib_compare -b hour ${INPUT} ${TEMP}
+${examples_dir}/c_grib_copy_message ${INPUT} ${TEMP}  > /dev/null
+${tools_dir}/grib_compare -b hour ${INPUT} ${TEMP}
 
 INPUT=${data_dir}/sample.grib2
-${examples_dir}c_grib_copy_message ${INPUT} ${TEMP}  > /dev/null
-${tools_dir}grib_compare -b hour ${INPUT} ${TEMP}
+${examples_dir}/c_grib_copy_message ${INPUT} ${TEMP}  > /dev/null
+${tools_dir}/grib_compare -b hour ${INPUT} ${TEMP}
 
 rm -f ${TEMP}
