@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2017 ECMWF.
+ * Copyright 2005-2018 ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -22,7 +22,7 @@ int main(int argc, char * argv[])
     int ret;
     int i, j;
     int count=0;
-    size_t paramIdSize, numberSize, values_len;
+    size_t paramIdSize, numberSize, values_len=0;
     char** paramId;
     long* number;
     double* values;
