@@ -1,4 +1,4 @@
-# Copyright 2005-2017 ECMWF.
+# Copyright 2005-2018 ECMWF.
 #
 # This software is licensed under the terms of the Apache Licence Version 2.0
 # which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -12,17 +12,11 @@ if [ -f "$CMAKE_INCLUDE_FILE" ]; then
   . ./$CMAKE_INCLUDE_FILE
 
 else
-  set -ea
+  set -eax
 
   echo
   echo "TEST: $0"
 
-  # If this environment variable is set, then become verbose
-  # so one can see why and how a test failed
-  if test "x$ECCODES_TEST_VERBOSE_OUTPUT" != "x"; then
-     set -x
-  fi
-
   if [ -z "${data_dir}" ]
   then
     cd ../../
