@@ -1,5 +1,5 @@
 #
-# Copyright 2005-2017 ECMWF.
+# Copyright 2005-2018 ECMWF.
 #
 # This software is licensed under the terms of the Apache Licence Version 2.0
 # which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -22,7 +22,7 @@ VERBOSE = 1  # verbose error reporting
 
 
 def example(INPUT):
-    f = open(INPUT)
+    f = open(INPUT, 'rb')
 
     while 1:
         gid = codes_grib_new_from_file(f)
