@@ -10,6 +10,13 @@ public :: codes_skip_computed, &
           codes_skip_read_only
 public :: codes_keys_iterator_get_name, &
           codes_keys_iterator_rewind
+          
+public :: codes_bufr_keys_iterator_new, &
+          codes_bufr_keys_iterator_next, &
+          codes_bufr_keys_iterator_get_name, &
+          codes_bufr_keys_iterator_rewind, &
+          codes_bufr_keys_iterator_delete
+
 public :: codes_new_from_message, &
           codes_grib_new_from_samples, codes_new_from_file, &
           codes_bufr_new_from_samples, &
@@ -27,3 +34,4 @@ public :: codes_clone, codes_copy_namespace
 public :: codes_index_get,codes_index_select,&
           codes_index_create,codes_index_get_size,codes_index_release,&
           codes_grib_util_sections_copy
+public :: codes_datetime_to_julian,codes_julian_to_datetime,codes_copy_key
