@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2017 ECMWF.
+ * Copyright 2005-2018 ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -157,9 +157,9 @@ int any_f_new_from_loaded_(int* msgid,int* gid);
 int any_f_new_from_loaded__(int* msgid,int* gid);
 int any_f_new_from_loaded(int* msgid,int* gid);
 
-int codes_f_clear_loaded_from_file_();
-int codes_f_clear_loaded_from_file__();
-int codes_f_clear_loaded_from_file();
+int codes_f_clear_loaded_from_file_(void);
+int codes_f_clear_loaded_from_file__(void);
+int codes_f_clear_loaded_from_file(void);
 
 int grib_f_new_from_file_(int *fid, int *gid);
 int grib_f_new_from_file__(int *fid, int *gid);
