@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2017 ECMWF.
+ * Copyright 2005-2018 ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -146,7 +146,7 @@ static void dump(grib_accessor* a, grib_dumper* dumper)
   grib_dump_double(dumper,a,NULL);
 
 }
-static int units[] =  {
+static const int units[] =  {
   0,      /* (0) minutes */
   1,      /* (1) hour    */
   24,     /* (2) day */
