@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2016 ECMWF.
+ * Copyright 2005-2018 ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -143,11 +143,16 @@ static void dump(grib_accessor* a,grib_dumper* dumper)
 
 static int unpack_string(grib_accessor*a , char*  v, size_t *len)
 {
+    int err = 0;
     long val = 0;
     size_t l = 1;
     char repres[1024];
 
-    grib_unpack_long (a , &val, &l);
+    err = grib_unpack_long (a , &val, &l);
+    /* TODO: We should catch all errors but in this case the test ERA_Gen.sh will fail
+     * as the output from grib_ls will be different */
+    /* if (err) return err; */
+    (void)err;
 
     if ((val == GRIB_MISSING_LONG) && ((a->flags & GRIB_ACCESSOR_FLAG_CAN_BE_MISSING) != 0) )
         sprintf(repres,"MISSING");
@@ -158,7 +163,6 @@ static int unpack_string(grib_accessor*a , char*  v, size_t *len)
 
     if(l >*len ){
         grib_context_log(a->context, GRIB_LOG_ERROR, "grib_accessor_long : unpack_string : Buffer too small for %s ", a->name );
-
         *len = l;
         return GRIB_BUFFER_TOO_SMALL;
     }
@@ -172,7 +176,6 @@ static int unpack_string(grib_accessor*a , char*  v, size_t *len)
 
 static int pack_missing(grib_accessor* a)
 {
-
     size_t one = 1;
     long value = GRIB_MISSING_LONG;
 
@@ -182,7 +185,6 @@ static int pack_missing(grib_accessor* a)
     return GRIB_VALUE_CANNOT_BE_MISSING;
 }
 
-
 /*
 static int is_missing(grib_accessor* a){
 
