@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2017 ECMWF.
+ * Copyright 2005-2018 ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -136,73 +136,72 @@ static void init_class(grib_accessor_class* c)
 
 static void init(grib_accessor* a,const long l, grib_arguments* c)
 {
-	int n=0;
-	grib_accessor_mars_param* self = (grib_accessor_mars_param*)a;
-	self->paramId= grib_arguments_get_name(grib_handle_of_accessor(a),c,n++);
-	self->table= grib_arguments_get_name(grib_handle_of_accessor(a),c,n++);
-	self->param= grib_arguments_get_name(grib_handle_of_accessor(a),c,n++);
+    int n=0;
+    grib_accessor_mars_param* self = (grib_accessor_mars_param*)a;
+    self->paramId= grib_arguments_get_name(grib_handle_of_accessor(a),c,n++);
+    self->table= grib_arguments_get_name(grib_handle_of_accessor(a),c,n++);
+    self->param= grib_arguments_get_name(grib_handle_of_accessor(a),c,n++);
 }
 
 static int pack_string(grib_accessor* a, const char* val, size_t *len){
 #if 1
-	return GRIB_NOT_IMPLEMENTED;
+    return GRIB_NOT_IMPLEMENTED;
 #else
-	grib_accessor_mars_param* self = (grib_accessor_mars_param*)a; 
-	long paramId=0;
-	long param=0;
-	long table=0;
-	char* p=(char*)val;
-	char* q=NULL;
+    grib_accessor_mars_param* self = (grib_accessor_mars_param*)a;
+    long paramId=0;
+    long param=0;
+    long table=0;
+    char* p=(char*)val;
+    char* q=NULL;
 
-	param=strtol(val, &p,10);
-	if ( *p!=0 ) table=strtol(++p, &q,10);
-	else table=128;
+    param=strtol(val, &p,10);
+    if ( *p!=0 ) table=strtol(++p, &q,10);
+    else table=128;
 
-	paramId=table*1000+param;
+    paramId=table*1000+param;
 
-	return grib_set_long_internal(grib_handle_of_accessor(a),self->paramId,paramId);
-#endif		
+    return grib_set_long_internal(grib_handle_of_accessor(a),self->paramId,paramId);
+#endif
 }
 
-
-static int    unpack_string(grib_accessor* a, char* val, size_t *len)
+static int unpack_string(grib_accessor* a, char* val, size_t *len)
 {   
-	grib_accessor_mars_param* self = (grib_accessor_mars_param*)a; 
-	long param=0;
-	long table=0;
-	int ret=0;
+    grib_accessor_mars_param* self = (grib_accessor_mars_param*)a;
+    long param=0;
+    long table=0;
+    int ret=0;
 
 #if 1
-	if(self->table!=NULL && (ret = grib_get_long_internal(grib_handle_of_accessor(a),self->table,&table)) != GRIB_SUCCESS) return ret;
-	if(self->param!=NULL && (ret = grib_get_long_internal(grib_handle_of_accessor(a),self->param,&param)) != GRIB_SUCCESS) return ret;
+    if(self->table!=NULL && (ret = grib_get_long_internal(grib_handle_of_accessor(a),self->table,&table)) != GRIB_SUCCESS) return ret;
+    if(self->param!=NULL && (ret = grib_get_long_internal(grib_handle_of_accessor(a),self->param,&param)) != GRIB_SUCCESS) return ret;
 #else
-	{
-	long paramId=0;
-	grib_get_long(grib_handle_of_accessor(a),self->paramId,&paramId);
+    {
+        long paramId=0;
+        grib_get_long(grib_handle_of_accessor(a),self->paramId,&paramId);
 
-	if (paramId==0 || (paramId < 4000 && paramId > 1000 )) {
-		if(self->table!=NULL && (ret = grib_get_long_internal(grib_handle_of_accessor(a),self->table,&table))
-				  != GRIB_SUCCESS) return ret;
-		if(self->param!=NULL && (ret = grib_get_long_internal(grib_handle_of_accessor(a),self->param,&param))
-				 != GRIB_SUCCESS) return ret;
-	} else if (paramId<1000) {
-		table=128;
-		param=paramId;
-	} else {
-    	table=paramId/1000;
-		param=paramId-table*1000;
-	}
-	}
+        if (paramId==0 || (paramId < 4000 && paramId > 1000 )) {
+            if(self->table!=NULL && (ret = grib_get_long_internal(grib_handle_of_accessor(a),self->table,&table))
+                    != GRIB_SUCCESS) return ret;
+            if(self->param!=NULL && (ret = grib_get_long_internal(grib_handle_of_accessor(a),self->param,&param))
+                    != GRIB_SUCCESS) return ret;
+        } else if (paramId<1000) {
+            table=128;
+            param=paramId;
+        } else {
+            table=paramId/1000;
+            param=paramId-table*1000;
+        }
+    }
 #endif
 
-	/*if (table==200) table=128;*/
-	sprintf(val,"%ld.%ld",param,table);
-	
-	return GRIB_SUCCESS;
+    /*if (table==200) table=128;*/
+    sprintf(val,"%ld.%ld",param,table);
+    *len = strlen(val)+1;
+
+    return GRIB_SUCCESS;
 }
 
 static size_t string_length(grib_accessor* a)
 {
     return 7;
 }
-
