@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2017 ECMWF.
+ * Copyright 2005-2018 ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -156,20 +156,152 @@ static void init_class(grib_accessor_class* c)
 static void init(grib_accessor* a,const long l, grib_arguments* c)
 {
     int n=0;
+    grib_handle* h = grib_handle_of_accessor(a);
     grib_accessor_number_of_points_gaussian* self = (grib_accessor_number_of_points_gaussian*)a;
-    self->ni = grib_arguments_get_name(grib_handle_of_accessor(a),c,n++);
-    self->nj = grib_arguments_get_name(grib_handle_of_accessor(a),c,n++);
-    self->plpresent = grib_arguments_get_name(grib_handle_of_accessor(a),c,n++);
-    self->pl = grib_arguments_get_name(grib_handle_of_accessor(a),c,n++);
-    self->order = grib_arguments_get_name(grib_handle_of_accessor(a),c,n++);
-    self->lat_first = grib_arguments_get_name(grib_handle_of_accessor(a),c,n++);
-    self->lon_first = grib_arguments_get_name(grib_handle_of_accessor(a),c,n++);
-    self->lat_last = grib_arguments_get_name(grib_handle_of_accessor(a),c,n++);
-    self->lon_last = grib_arguments_get_name(grib_handle_of_accessor(a),c,n++);
+    self->ni = grib_arguments_get_name(h,c,n++);
+    self->nj = grib_arguments_get_name(h,c,n++);
+    self->plpresent = grib_arguments_get_name(h,c,n++);
+    self->pl = grib_arguments_get_name(h,c,n++);
+    self->order = grib_arguments_get_name(h,c,n++);
+    self->lat_first = grib_arguments_get_name(h,c,n++);
+    self->lon_first = grib_arguments_get_name(h,c,n++);
+    self->lat_last = grib_arguments_get_name(h,c,n++);
+    self->lon_last = grib_arguments_get_name(h,c,n++);
     a->flags  |= GRIB_ACCESSOR_FLAG_READ_ONLY;
     a->flags |= GRIB_ACCESSOR_FLAG_FUNCTION;
     a->length=0;
 }
+#if 0
+/*Legacy mode*/
+static long num_points_reduced_gauss_old(grib_handle* h, long nj, long pl[],
+                                         long max_pl, double lats[],
+                                         double angular_precision,
+                                         double lat_first, double lat_last,
+                                         double lon_first, double lon_last)
+{
+    long result=0;
+    int is_global=0;
+    size_t plsize=0;
+    long ilon_first=0,ilon_last=0;
+    double lon_first_row=0,lon_last_row=0;
+    float d = 0;
+    is_global=is_gaussian_global(lat_first,lat_last,lon_first,lon_last,max_pl,lats,angular_precision);
+    d=fabs(lats[0]-lats[1]);
+    if ( !is_global ) {
+        long j = 0;
+        /*sub area*/
+        (void)d;
+#if EFDEBUG
+        printf("-------- subarea fabs(lat_first-lats[0])=%g d=%g\n",fabs(lat_first-lats[0]),d);
+        printf("-------- subarea fabs(lat_last+lats[0])=%g d=%g\n",fabs(lat_last+lats[0]),d);
+        printf("-------- subarea lon_last=%g order=%ld 360.0-90.0/order=%g\n",
+                lon_last,order,360.0-90.0/order);
+        printf("-------- subarea lon_first=%g fabs(lon_last  -( 360.0-90.0/order))=%g 90.0/order=%g\n",
+                lon_first,fabs(lon_last  - (360.0-90.0/order)),90.0/order);
+#endif
+        for (j=0;j<nj;j++) {
+            long row_count=0;
+#if EFDEBUG
+            printf("--  %d ",j);
+#endif
+            grib_get_reduced_row(pl[j],lon_first,lon_last,&row_count,&ilon_first,&ilon_last);
+            lon_first_row=((ilon_first)*360.0)/pl[j];
+            lon_last_row=((ilon_last)*360.0)/pl[j];
+            result += row_count;
+            (void)lon_last_row;
+            (void)lon_first_row;
+#if EFDEBUG
+            printf("        ilon_first=%ld lon_first=%.10e ilon_last=%ld lon_last=%.10e count=%ld row_count=%ld\n",
+                    ilon_first,lon_first_row,ilon_last,lon_last_row,result,row_count);
+#endif
+        }
+    } else {
+        int i = 0;
+        result=0;
+        for (i=0;i<plsize;i++) result += pl[i];
+    }
+    return result;
+}
+
+/* New MIR compatible way */
+static long num_points_reduced_gauss_new(grib_handle* h, long nj, long pl[], double lon_first, double lon_last)
+{
+    long result = 0;
+    long j;
+    /* Always assume sub area */
+    for (j=0;j<nj;j++) {
+        long row_count=0;
+        long ilon_first=0,ilon_last=0;
+        grib_get_reduced_row2(pl[j], lon_first, lon_last, &row_count, &ilon_first, &ilon_last);
+        result += row_count;
+    }
+    return result;
+}
+#endif
+
+static int angleApproximatelyEqual(double A, double B, double angular_precision)
+{
+    return angular_precision > 0 ? (fabs(A-B)<=angular_precision) : (A == B);
+}
+
+static double longitude_normalise(double lon, double minimum)
+{
+    while (lon < minimum) {
+        lon += 360;
+    }
+    while (lon >= minimum + 360) {
+        lon -= 360;
+    }
+    return lon;
+}
+
+static void correctWestEast(long max_pl, double angular_precision, double* pWest, double* pEast)
+{
+    double w, e;
+    const double inc = 360.0/max_pl; /*smallest increment*/
+    if (*pWest > *pEast) *pEast += 360;
+
+    w = *pWest;
+    e = *pEast;
+
+    if (angleApproximatelyEqual(0, w, angular_precision)) {
+        const int cond1 = angleApproximatelyEqual(360 - inc, e - w, angular_precision);
+        const int cond2 = (360 - inc < e - w);
+        const int cond3 = (e != w);
+        const int cond4 = longitude_normalise(e,w)==w;    /* e.normalise(w) == w */
+        if ( cond1 || cond2 || (cond3 && cond4) ) {
+            *pWest = 0;
+            *pEast = 360 - inc;
+        }
+    }
+}
+
+static int get_number_of_data_values(grib_handle* h, size_t* numDataValues)
+{
+    int err = 0;
+    long bpv=0, bitmapPresent=0;
+    size_t bitmapLength = 0;
+
+    if ( (err = grib_get_long(h, "bitsPerValue", &bpv)) ) return err;
+
+    if (bpv != 0) {
+        if (grib_get_size(h, "values", numDataValues)==GRIB_SUCCESS) {
+            return GRIB_SUCCESS;
+        }
+    } else {
+        /* Constant field (with or without bitmap) */
+        if ( (err = grib_get_long(h,"bitmapPresent", &bitmapPresent)) ) return err;
+        if (bitmapPresent) {
+            if ( (err = grib_get_size(h,"bitmap", &bitmapLength)) ) return err;
+            *numDataValues = bitmapLength;
+            return GRIB_SUCCESS;
+        } else {
+            err = GRIB_NO_VALUES; /* Cannot determine number of values */
+        }
+    }
+
+    return err;
+}
 
 static int unpack_long(grib_accessor* a, long* val, size_t *len)
 {
@@ -185,22 +317,24 @@ static int unpack_long(grib_accessor* a, long* val, size_t *len)
     long ilon_first=0,ilon_last=0;
     double angular_precision = 1.0/1000000.0;
     long editionNumber = 0;
+    grib_handle* h = grib_handle_of_accessor(a);
+    size_t numDataValues=0;
 
     grib_accessor_number_of_points_gaussian* self = (grib_accessor_number_of_points_gaussian*)a;
     grib_context* c=a->context;
 
-    if((ret = grib_get_long_internal(grib_handle_of_accessor(a), self->ni,&ni)) != GRIB_SUCCESS)
+    if((ret = grib_get_long_internal(h, self->ni,&ni)) != GRIB_SUCCESS)
         return ret;
 
-    if((ret = grib_get_long_internal(grib_handle_of_accessor(a), self->nj,&nj)) != GRIB_SUCCESS)
+    if((ret = grib_get_long_internal(h, self->nj,&nj)) != GRIB_SUCCESS)
         return ret;
 
-    if((ret = grib_get_long_internal(grib_handle_of_accessor(a), self->plpresent,&plpresent)) != GRIB_SUCCESS)
+    if((ret = grib_get_long_internal(h, self->plpresent,&plpresent)) != GRIB_SUCCESS)
         return ret;
 
     if (nj == 0) return GRIB_GEOCALCULUS_PROBLEM;
 
-    if (grib_get_long(grib_handle_of_accessor(a), "editionNumber", &editionNumber)==GRIB_SUCCESS) {
+    if (grib_get_long(h, "editionNumber", &editionNumber)==GRIB_SUCCESS) {
         if (editionNumber == 1) angular_precision = 1.0/1000;
     }
 
@@ -211,27 +345,27 @@ static int unpack_long(grib_accessor* a, long* val, size_t *len)
         double lon_first_row=0,lon_last_row=0;
 
         /*reduced*/
-        if((ret = grib_get_long_internal(grib_handle_of_accessor(a), self->order,&order)) != GRIB_SUCCESS)
+        if((ret = grib_get_long_internal(h, self->order,&order)) != GRIB_SUCCESS)
             return ret;
-        if((ret = grib_get_double_internal(grib_handle_of_accessor(a), self->lat_first,&lat_first)) != GRIB_SUCCESS)
+        if((ret = grib_get_double_internal(h, self->lat_first,&lat_first)) != GRIB_SUCCESS)
             return ret;
-        if((ret = grib_get_double_internal(grib_handle_of_accessor(a), self->lon_first,&lon_first)) != GRIB_SUCCESS)
+        if((ret = grib_get_double_internal(h, self->lon_first,&lon_first)) != GRIB_SUCCESS)
             return ret;
-        if((ret = grib_get_double_internal(grib_handle_of_accessor(a), self->lat_last,&lat_last)) != GRIB_SUCCESS)
+        if((ret = grib_get_double_internal(h, self->lat_last,&lat_last)) != GRIB_SUCCESS)
             return ret;
-        if((ret = grib_get_double_internal(grib_handle_of_accessor(a), self->lon_last,&lon_last)) != GRIB_SUCCESS)
+        if((ret = grib_get_double_internal(h, self->lon_last,&lon_last)) != GRIB_SUCCESS)
             return ret;
 
         lats=(double*)grib_context_malloc(a->context,sizeof(double)*order*2);
         if((ret = grib_get_gaussian_latitudes(order, lats)) != GRIB_SUCCESS)
             return ret;
 
-        if((ret = grib_get_size(grib_handle_of_accessor(a),self->pl,&plsize)) != GRIB_SUCCESS)
+        if((ret = grib_get_size(h,self->pl,&plsize)) != GRIB_SUCCESS)
             return ret;
 
         pl=(long*)grib_context_malloc_clear(c,sizeof(long)*plsize);
         plsave=pl;
-        grib_get_long_array_internal(grib_handle_of_accessor(a),self->pl,pl, &plsize);
+        grib_get_long_array_internal(h,self->pl,pl, &plsize);
 
         if (lon_last<0) lon_last+=360;
         if (lon_first<0) lon_first+=360;
@@ -243,8 +377,12 @@ static int unpack_long(grib_accessor* a, long* val, size_t *len)
             if (pl[j] > max_pl) max_pl = pl[j];
         }
 
-        is_global=is_gaussian_global(lat_first,lat_last,lon_first,lon_last,max_pl,lats,angular_precision);
+        /*is_global=is_gaussian_global(lat_first,lat_last,lon_first,lon_last,max_pl,lats,angular_precision);*/
         d=fabs(lats[0]-lats[1]);
+        is_global = 0; /* ECC-445 */
+
+        correctWestEast(max_pl, angular_precision, &lon_first, &lon_last);
+
         if ( !is_global ) {
             /*sub area*/
             (void)d;
@@ -262,7 +400,12 @@ static int unpack_long(grib_accessor* a, long* val, size_t *len)
 #if EFDEBUG
                 printf("--  %d ",j);
 #endif
-                grib_get_reduced_row(pl[j],lon_first,lon_last,&row_count,&ilon_first,&ilon_last);
+                grib_get_reduced_row_wrapper(h, pl[j],lon_first,lon_last,&row_count,&ilon_first,&ilon_last);
+#if 0
+                if ( row_count != pl[j] ) {
+                    printf("oops...... rc=%ld but pl[%d]=%ld\n", row_count, j,pl[j]);
+                }
+#endif
                 lon_first_row=((ilon_first)*360.0)/pl[j];
                 lon_last_row=((ilon_last)*360.0)/pl[j];
                 *val+=row_count;
@@ -288,5 +431,16 @@ static int unpack_long(grib_accessor* a, long* val, size_t *len)
 #endif
     if (lats) grib_context_free(c,lats);
     if (plsave) grib_context_free(c,plsave);
+
+    /* ECC-756: Now decide whether this is legacy GRIB1 message. */
+    /* Query data values to see if there is a mismatch */
+    if (get_number_of_data_values(h, &numDataValues) == GRIB_SUCCESS) {
+        if (*val != numDataValues) {
+            if (h->context->debug)
+                printf("ECCODES DEBUG number_of_points_gaussian: LEGACY MODE activated. Count(=%ld) changed to size(values)\n",*val);
+            *val = numDataValues;
+        }
+    }
+
     return ret;
 }
