@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2017 ECMWF.
+ * Copyright 2005-2018 ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -10,7 +10,7 @@
 
 /**
     include private headers used for all internal functions of
-    grib_api, not seen by the user of the API
+    ecCodes, not seen by the user of the API
   */
 
 #ifndef grib_api_internal_H
@@ -58,7 +58,6 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 
-/* Microsoft Windows Visual Studio support */
 #include "eccodes_windef.h"
 
 #ifndef ECCODES_ON_WINDOWS
@@ -790,7 +789,7 @@ struct bufr_descriptor {
   char*  units;
   long   scale;
   double factor;
-  double reference;
+  long   reference;
   long   width;
   int    nokey; /* set if descriptor does not have an associated key */
   grib_accessor* a;
@@ -811,12 +810,12 @@ struct bufr_descriptors_map_list {
   bufr_descriptors_map_list* next;
 };
 
-/* BUFR: operator 203: Table B changed reference values */
+/* BUFR: Operator 203YYY: Linked list storing Table B changed reference values */
 typedef struct bufr_tableb_override bufr_tableb_override;
 struct bufr_tableb_override {
   bufr_tableb_override* next;
   int                   code;
-  double                new_ref_val;
+  long                  new_ref_val;
 };
 
 struct codes_condition {
@@ -1385,7 +1384,7 @@ struct bufr_keys_iterator{
   unsigned long     accessor_flags_skip;
   unsigned long     accessor_flags_only;
   grib_accessor*    current;
-  grib_string_list* names;
+  char*             key_name;
   int               at_start;
   int               match;
   int               i_curr_attribute;
@@ -1506,7 +1505,6 @@ typedef struct j2k_encode_helper {
 
 } j2k_encode_helper;
 
-
 #include "grib_api_prototypes.h"
 
 
