@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2017 ECMWF.
+ * Copyright 2005-2018 ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -21,13 +21,13 @@ bufr_descriptor* grib_bufr_descriptor_new(grib_accessor* tables_accessor,int cod
 
 bufr_descriptor* grib_bufr_descriptor_clone(bufr_descriptor* d)
 {
-
     bufr_descriptor* cd;
 
     if (!d) return NULL;
 
     cd=(bufr_descriptor*)grib_context_malloc_clear(d->context,sizeof(bufr_descriptor));
 
+    cd->context=d->context;
     cd->code=d->code;
     cd->F=d->F;
     cd->X=d->X;
@@ -84,7 +84,7 @@ int grib_bufr_descriptor_set_code(grib_accessor* tables_accessor,int code,bufr_d
     return err;
 }
 
-void grib_bufr_descriptor_set_reference(bufr_descriptor* v,double reference)
+void grib_bufr_descriptor_set_reference(bufr_descriptor* v,long reference)
 {
     if (!v) return;
     v->reference=reference;
