@@ -146,7 +146,7 @@ static int destroy(grib_dumper* d)
 
 static char* lval_to_string(grib_context* c, long v)
 {
-    char* sval=grib_context_malloc_clear(c,sizeof(char)*40);
+    char* sval=(char*)grib_context_malloc_clear(c,sizeof(char)*40);
     if (v == GRIB_MISSING_LONG) sprintf(sval,"CODES_MISSING_LONG");
     else                        sprintf(sval,"%ld",v);
     return sval;
@@ -174,12 +174,11 @@ static char* dval_to_string(grib_context* c, double v)
 static char* break_line(grib_context* c, const char* input)
 {
     /* Break a long line using Fortran continuation characters */
-    char* result=NULL;
     char* a_token = NULL;
     int first = 1;
     const size_t len = strlen(input);
     /* Add a bit more for inserted newlines and continuation characters */
-    result = (char*)grib_context_malloc_clear(c,sizeof(char)*len+100);
+    char* result = (char*)grib_context_malloc_clear(c,sizeof(char)*len+100);
 
     /* No need to alter input which is already too short or has newlines */
     if (len < 70 || strchr(input, '\n')) {
@@ -376,9 +375,11 @@ static void dump_long(grib_dumper* d,grib_accessor* a, const char* comment)
     char* sval = NULL;
     grib_context* c=a->context;
     grib_handle* h=grib_handle_of_accessor(a);
+    int doing_unexpandedDescriptors=0;
 
     if ( (a->flags & GRIB_ACCESSOR_FLAG_DUMP) == 0  ) return;
 
+    doing_unexpandedDescriptors = (strcmp(a->name, "unexpandedDescriptors")==0);
     grib_value_count(a,&count);
     size=count;
 
@@ -428,20 +429,23 @@ static void dump_long(grib_dumper* d,grib_accessor* a, const char* comment)
         fprintf(self->dumper.out,"/)\n");
         grib_context_free(a->context,values);
 
-        if ((r=compute_bufr_key_rank(h,self->keys,a->name))!=0)
+        if ((r=compute_bufr_key_rank(h,self->keys,a->name))!=0) {
             fprintf(self->dumper.out,"  call codes_set(ibufr,'#%d#%s',ivalues)\n",r,a->name);
-        else
+        } else {
+            if (doing_unexpandedDescriptors) {
+                fprintf(self->dumper.out,"\n  ! Create the structure of the data section\n");
+            }
             fprintf(self->dumper.out,"  call codes_set(ibufr,'%s',ivalues)\n",a->name);
+            if (doing_unexpandedDescriptors) fprintf(self->dumper.out,"\n");
+        }
 
     } else {
-        int doing_unexpandedDescriptors=0;
         r=compute_bufr_key_rank(h,self->keys,a->name);
         sval=lval_to_string(c,value);
         if (r!=0) {
             fprintf(self->dumper.out,"  call codes_set(ibufr,'#%d#%s',",r,a->name);
         } else {
-            if (strcmp(a->name, "unexpandedDescriptors")==0) {
-                doing_unexpandedDescriptors=1;
+            if (doing_unexpandedDescriptors) {
                 fprintf(self->dumper.out,"\n  ! Create the structure of the data section\n");
             }
             fprintf(self->dumper.out,"  call codes_set(ibufr,'%s',",a->name);
@@ -449,8 +453,7 @@ static void dump_long(grib_dumper* d,grib_accessor* a, const char* comment)
 
         fprintf(self->dumper.out,"%s)\n",sval);
         grib_context_free(c,sval);
-        if (doing_unexpandedDescriptors)
-            fprintf(self->dumper.out,"\n");
+        if (doing_unexpandedDescriptors) fprintf(self->dumper.out,"\n");
     }
 
     if (self->isLeaf==0) {
@@ -592,14 +595,12 @@ static void dump_string_array(grib_dumper* d, grib_accessor* a, const char* comm
     grib_dumper_bufr_encode_fortran *self = (grib_dumper_bufr_encode_fortran*)d;
     char **values;
     size_t size = 0,i=0;
-    grib_context* c=NULL;
+    grib_context* c=a->context;
     int err = 0;
     long count=0;
     int r = 0;
     grib_handle* h=grib_handle_of_accessor(a);
 
-    c=a->context;
-
     if ( (a->flags & GRIB_ACCESSOR_FLAG_DUMP) == 0 || (a->flags & GRIB_ACCESSOR_FLAG_READ_ONLY) != 0)
         return;
 
@@ -662,16 +663,25 @@ static void dump_string(grib_dumper* d, grib_accessor* a, const char* comment)
     char *value=NULL;
     char *p = NULL;
     size_t size = 0;
-    grib_context* c=NULL;
+    grib_context* c=a->context;
     int r;
     int err = _grib_get_string_length(a,&size);
     grib_handle* h=grib_handle_of_accessor(a);
+    const char* acc_name = a->name;
 
-    c=a->context;
     if (size==0) return;
 
-    if ( (a->flags & GRIB_ACCESSOR_FLAG_DUMP) == 0 || (a->flags & GRIB_ACCESSOR_FLAG_READ_ONLY) != 0)
-        return;
+    if ( (a->flags & GRIB_ACCESSOR_FLAG_DUMP) == 0 || (a->flags & GRIB_ACCESSOR_FLAG_READ_ONLY) != 0) {
+        /* ECC-356: Solution for the special local section key 'keyMore' and its alias 'ident' */
+        int skip = 1;
+        if ( (a->flags & GRIB_ACCESSOR_FLAG_HIDDEN)!=0 ) {
+            if ( strcmp(a->name, "keyMore")==0 && grib_is_defined(h, "ls.ident") ) {
+                skip = 0;
+                acc_name = "ident";
+            }
+        }
+        if (skip) return;
+    }
 
     value=(char*)grib_context_malloc_clear(c,size);
     if (!value) {
@@ -683,7 +693,7 @@ static void dump_string(grib_dumper* d, grib_accessor* a, const char* comment)
 
     err = grib_unpack_string(a,value,&size);
     p=value;
-    r=compute_bufr_key_rank(h,self->keys,a->name);
+    r=compute_bufr_key_rank(h,self->keys,acc_name);
     if (grib_is_missing_string(a,(unsigned char *)value,size)) {
         strcpy(value, ""); /* Empty string means MISSING string */
     }
@@ -693,9 +703,9 @@ static void dump_string(grib_dumper* d, grib_accessor* a, const char* comment)
     if (self->isLeaf==0) {
         depth+=2;
         if (r!=0)
-            fprintf(self->dumper.out,"  call codes_set(ibufr,'#%d#%s',",r,a->name);
+            fprintf(self->dumper.out,"  call codes_set(ibufr,'#%d#%s',",r,acc_name);
         else
-            fprintf(self->dumper.out,"  call codes_set(ibufr,'%s',",a->name);
+            fprintf(self->dumper.out,"  call codes_set(ibufr,'%s',",acc_name);
     }
     fprintf(self->dumper.out,"\'%s\')\n",value);
 
@@ -705,10 +715,10 @@ static void dump_string(grib_dumper* d, grib_accessor* a, const char* comment)
         int dofree=0;
 
         if (r!=0) {
-            prefix=(char*)grib_context_malloc_clear(c,sizeof(char)*(strlen(a->name)+10));
+            prefix=(char*)grib_context_malloc_clear(c,sizeof(char)*(strlen(acc_name)+10));
             dofree=1;
-            sprintf(prefix,"#%d#%s",r,a->name);
-        } else prefix=(char*)a->name;
+            sprintf(prefix,"#%d#%s",r,acc_name);
+        } else prefix=(char*)acc_name;
 
         dump_attributes(d,a,prefix);
         if (dofree) grib_context_free(c,prefix);
@@ -874,7 +884,8 @@ static void footer(grib_dumper* d, grib_handle* h)
     fprintf(self->dumper.out,"  call codes_write(ibufr,outfile)\n");
     fprintf(self->dumper.out,"  call codes_close_file(outfile)\n");
     fprintf(self->dumper.out,"  call codes_release(ibufr)\n");
-    fprintf(self->dumper.out,"  print *, \"Created output BUFR file 'outfile.bufr'\"\n");
+    if (d->count==1)
+        fprintf(self->dumper.out,"  print *, \"Created output BUFR file 'outfile.bufr'\"\n");
     fprintf(self->dumper.out,"  if(allocated(ivalues)) deallocate(ivalues)\n");
     fprintf(self->dumper.out,"  if(allocated(rvalues)) deallocate(rvalues)\n");
     fprintf(self->dumper.out,"  if(allocated(svalues)) deallocate(svalues)\n");
