@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2017 ECMWF.
+ * Copyright 2005-2018 ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -110,8 +110,6 @@ struct string_count {
     string_count* next;
 };
 
-static int depth=0;
-
 static void init_class      (grib_dumper_class* c){}
 
 static int init(grib_dumper* d)
@@ -188,7 +186,6 @@ static void dump_values(grib_dumper* d, grib_accessor* a)
         if (icount>cols || i==0) {fprintf(self->dumper.out,"\n      ");icount=0;}
         fprintf(self->dumper.out, "%g",values[i]);
 
-        depth-=2;
         fprintf(self->dumper.out,"}\n");
         grib_context_free(c,values);
     } else {
@@ -217,7 +214,6 @@ static void dump_values(grib_dumper* d, grib_accessor* a)
 
         dump_attributes(d,a,prefix);
         if (dofree) grib_context_free(c,prefix);
-        depth-=2;
     }
 
     (void)err; /* TODO */
@@ -260,7 +256,6 @@ static void dump_values_attribute(grib_dumper* d,grib_accessor* a, const char* p
         if (icount>cols || i==0) {fprintf(self->dumper.out,"\n      ");icount=0;}
         fprintf(self->dumper.out,"%g", values[i]);
 
-        depth-=2;
         fprintf(self->dumper.out,"}\n");
         grib_context_free(c,values);
     } else {
@@ -281,7 +276,6 @@ static void dump_values_attribute(grib_dumper* d,grib_accessor* a, const char* p
         dump_attributes(d,a,prefix1);
 
         grib_context_free(c,prefix1);
-        depth-=2;
     }
 
     (void)err; /* TODO */
@@ -319,7 +313,6 @@ static void dump_long(grib_dumper* d, grib_accessor* a, const char* comment)
             
             dump_attributes(d,a,prefix);
             if (dofree) grib_context_free(c,prefix);
-            depth-=2;
         }
         return;
     }
@@ -335,6 +328,7 @@ static void dump_long(grib_dumper* d, grib_accessor* a, const char* comment)
     self->empty=0;
 
     if (size>1) {
+        int doing_unexpandedDescriptors=0;
         icount=0;
         if ((r=compute_bufr_key_rank(h,self->keys,a->name))!=0)
             fprintf(self->dumper.out,"#%d#%s=",r,a->name);
@@ -342,16 +336,23 @@ static void dump_long(grib_dumper* d, grib_accessor* a, const char* comment)
             fprintf(self->dumper.out,"%s=",a->name);
 
         fprintf(self->dumper.out,"{");
+        if (strcmp(a->name, "unexpandedDescriptors")==0)
+            doing_unexpandedDescriptors = 1;
 
         for (i=0;i<size-1;i++) {
             if (icount>cols || i==0) {fprintf(self->dumper.out,"\n      ");icount=0;}
-            fprintf(self->dumper.out,"%ld, ",values[i]);
+            if (doing_unexpandedDescriptors)
+                fprintf(self->dumper.out,"%06ld, ",values[i]);
+            else
+                fprintf(self->dumper.out,"%ld, ",values[i]);
             icount++;
         }
         if (icount>cols || i==0) {fprintf(self->dumper.out,"\n      ");icount=0;}
-        fprintf(self->dumper.out,"%ld ",values[i]);
+        if (doing_unexpandedDescriptors)
+            fprintf(self->dumper.out,"%06ld ",values[i]);
+        else
+            fprintf(self->dumper.out,"%ld ",values[i]);
 
-        depth-=2;
         fprintf(self->dumper.out,"}\n");
         grib_context_free(a->context,values);
     } else {
@@ -380,7 +381,6 @@ static void dump_long(grib_dumper* d, grib_accessor* a, const char* comment)
 
         dump_attributes(d,a,prefix);
         if (dofree) grib_context_free(c,prefix);
-        depth-=2;
     }
     (void)err; /* TODO */
 }
@@ -421,7 +421,6 @@ static void dump_long_attribute(grib_dumper* d, grib_accessor* a, const char* pr
         }
         if (icount>cols || i==0) {fprintf(self->dumper.out,"\n      ");icount=0;}
         fprintf(self->dumper.out,"%ld ",values[i]);
-        depth-=2;
         fprintf(self->dumper.out,"}\n");
         grib_context_free(a->context,values);
 
@@ -444,7 +443,6 @@ static void dump_long_attribute(grib_dumper* d, grib_accessor* a, const char* pr
         dump_attributes(d,a,prefix1);
 
         grib_context_free(c,prefix1);
-        depth-=2;
     }
     (void)err; /* TODO */
 }
@@ -493,7 +491,6 @@ static void dump_double(grib_dumper* d, grib_accessor* a, const char* comment)
 
         dump_attributes(d,a,prefix);
         if (dofree) grib_context_free(c,prefix);
-        depth-=2;
     }
 }
 
@@ -521,7 +518,6 @@ static void dump_string_array(grib_dumper* d, grib_accessor* a, const char* comm
     self->begin=0;
 
     if (self->isLeaf==0) {
-        depth+=2;
         if ((r=compute_bufr_key_rank(h,self->keys,a->name))!=0)
             fprintf(self->dumper.out,"#%d#%s=",r,a->name);
         else
@@ -539,14 +535,11 @@ static void dump_string_array(grib_dumper* d, grib_accessor* a, const char* comm
     err = grib_unpack_string_array(a,values,&size);
 
     fprintf(self->dumper.out, "{");
-    depth+=2;
     for  (i=0;i<size-1;i++) {
         fprintf(self->dumper.out,"    \"%s\",\n",values[i]);
     }
     fprintf(self->dumper.out,"    \"%s\"\n",values[i]);
 
-    depth-=2;
-
     fprintf(self->dumper.out, "}\n");
 
     if (self->isLeaf==0) {
@@ -561,7 +554,6 @@ static void dump_string_array(grib_dumper* d, grib_accessor* a, const char* comm
 
         dump_attributes(d,a,prefix);
         if (dofree) grib_context_free(c,prefix);
-        depth-=2;
     }
 
     grib_context_free(c,values);
@@ -576,14 +568,25 @@ static void dump_string(grib_dumper* d, grib_accessor* a, const char* comment)
     size_t size = 0;
     grib_context* c=NULL;
     int r = 0;
+    int is_missing = 0;
     int err = _grib_get_string_length(a,&size);
     grib_handle* h=grib_handle_of_accessor(a);
+    const char* acc_name = a->name;
 
     c=a->context;
     if (size==0) return;
 
-    if ( (a->flags & GRIB_ACCESSOR_FLAG_DUMP) == 0 || (a->flags & GRIB_ACCESSOR_FLAG_READ_ONLY) != 0)
-        return;
+    if ( (a->flags & GRIB_ACCESSOR_FLAG_DUMP) == 0 || (a->flags & GRIB_ACCESSOR_FLAG_READ_ONLY) != 0) {
+        /* ECC-356: Solution for the special local section key 'keyMore' and its alias 'ident' */
+        int skip = 1;
+        if ( (a->flags & GRIB_ACCESSOR_FLAG_HIDDEN)!=0 ) {
+            if ( strcmp(a->name, "keyMore")==0 && grib_is_defined(h, "ls.ident") ) {
+                skip = 0;
+                acc_name = "ident";
+            }
+        }
+        if (skip) return;
+    }
 
     value=(char*)grib_context_malloc_clear(c,size);
     if (!value) {
@@ -597,34 +600,34 @@ static void dump_string(grib_dumper* d, grib_accessor* a, const char* comment)
 
     err = grib_unpack_string(a,value,&size);
     p=value;
-    r=compute_bufr_key_rank(h,self->keys,a->name);
-    if (grib_is_missing_string(a,(unsigned char *)value,size))
-        return;
+    r=compute_bufr_key_rank(h,self->keys,acc_name);
+    if (grib_is_missing_string(a,(unsigned char *)value,size)) {
+        is_missing = 1;
+    }
 
     while(*p) { if(!isprint(*p)) *p = '.'; p++; }
 
     if (self->isLeaf==0) {
-        depth+=2;
         if (r!=0)
-            fprintf(self->dumper.out,"#%d#%s=",r,a->name);
+            fprintf(self->dumper.out,"#%d#%s=",r,acc_name);
         else
-            fprintf(self->dumper.out,"%s=",a->name);
+            fprintf(self->dumper.out,"%s=",acc_name);
     }
-    fprintf(self->dumper.out,"\"%s\"\n",value);
+    if (is_missing) fprintf(self->dumper.out,"%s\n", "MISSING");
+    else            fprintf(self->dumper.out,"\"%s\"\n",value);
 
     if (self->isLeaf==0) {
         char* prefix;
         int dofree=0;
 
         if (r!=0) {
-            prefix=(char*)grib_context_malloc_clear(c,sizeof(char)*(strlen(a->name)+10));
+            prefix=(char*)grib_context_malloc_clear(c,sizeof(char)*(strlen(acc_name)+10));
             dofree=1;
-            sprintf(prefix,"#%d#%s",r,a->name);
-        } else prefix=(char*)a->name;
+            sprintf(prefix,"#%d#%s",r,acc_name);
+        } else prefix=(char*)acc_name;
 
         dump_attributes(d,a,prefix);
         if (dofree) grib_context_free(c,prefix);
-        depth-=2;
     }
 
     grib_context_free(c,value);
@@ -639,17 +642,18 @@ static void dump_label(grib_dumper* d, grib_accessor* a, const char* comment)
 {
 }
 
-static void _dump_long_array(grib_handle* h, FILE* f, const char* key, const char* print_key)
+static void _dump_long_array(grib_handle* h, FILE* f, const char* key)
 {
     long* val;
     size_t size=0,i;
     int cols=9,icount=0;
 
     if (grib_get_size(h,key,&size)==GRIB_NOT_FOUND) return;
+    if (size==0) return;
 
     val=(long*)grib_context_malloc_clear(h->context,sizeof(long)*size);
     grib_get_long_array(h,key,val,&size);
-    fprintf(f,"%s= {",print_key);
+    fprintf(f,"%s= {", key);
     for (i=0;i<size-1;i++) {
         if (icount>cols || i==0) {fprintf(f,"\n      ");icount=0;}
         fprintf(f,"%ld, ",val[i]);
@@ -669,24 +673,21 @@ static void dump_section(grib_dumper* d, grib_accessor* a, grib_block_of_accesso
             !grib_inline_strcmp(a->name,"META")
     ) {
         grib_handle* h=grib_handle_of_accessor(a);
-        depth=2;
         self->begin=1;
         self->empty=1;
-        depth+=2;
-        _dump_long_array(h,self->dumper.out,"dataPresentIndicator","inputDataPresentIndicator");
-        _dump_long_array(h,self->dumper.out,"delayedDescriptorReplicationFactor","inputDelayedDescriptorReplicationFactor");
-        _dump_long_array(h,self->dumper.out,"shortDelayedDescriptorReplicationFactor","inputShortDelayedDescriptorReplicationFactor");
-        _dump_long_array(h,self->dumper.out,"extendedDelayedDescriptorReplicationFactor","inputExtendedDelayedDescriptorReplicationFactor");
+        _dump_long_array(h,self->dumper.out,"dataPresentIndicator");
+        _dump_long_array(h,self->dumper.out,"delayedDescriptorReplicationFactor");
+        _dump_long_array(h,self->dumper.out,"shortDelayedDescriptorReplicationFactor");
+        _dump_long_array(h,self->dumper.out,"extendedDelayedDescriptorReplicationFactor");
+        /* Do not show the inputOverriddenReferenceValues array. That's more for ENCODING */
+        /*_dump_long_array(h,self->dumper.out,"inputOverriddenReferenceValues","inputOverriddenReferenceValues");*/
         grib_dump_accessors_block(d,block);
-        depth-=2;
     } else if (!grib_inline_strcmp(a->name,"groupNumber")) {
         if ( (a->flags & GRIB_ACCESSOR_FLAG_DUMP) == 0)
             return;
         self->begin=1;
         self->empty=1;
-        depth+=2;
         grib_dump_accessors_block(d,block);
-        depth-=2;
     } else {
         grib_dump_accessors_block(d,block);
     }
