@@ -280,10 +280,9 @@ static void dump_bits(grib_dumper* d,grib_accessor* a,const char* comment)
 static void dump_double(grib_dumper* d,grib_accessor* a,const char* comment)
 {
     grib_dumper_default *self = (grib_dumper_default*)d;
-    double value; size_t size = 1;
+    double value=0; size_t size = 1;
     int err = grib_unpack_double(a,&value,&size);
 
-
     if ( (a->flags & GRIB_ACCESSOR_FLAG_DUMP) == 0)
         return;
 
@@ -312,7 +311,6 @@ static void dump_double(grib_dumper* d,grib_accessor* a,const char* comment)
     else
         fprintf(self->dumper.out,"%s = %g;",a->name,value);
 
-
     if(err) {
         fprintf(self->dumper.out,"  ");
         fprintf(self->dumper.out,"# *** ERR=%d (%s) [grib_dumper_default::dump_double]",err,grib_get_error_message(err));
@@ -351,7 +349,6 @@ static void dump_string_array(grib_dumper* d,grib_accessor* a,const char* commen
     if ( (a->flags & GRIB_ACCESSOR_FLAG_DUMP) == 0)
         return;
 
-
     print_offset(self->dumper.out,d,a);
 
     if ((d->option_flags & GRIB_DUMP_FLAG_TYPE) != 0) {
@@ -531,7 +528,7 @@ static void dump_values(grib_dumper* d,grib_accessor* a)
     grib_dumper_default *self = (grib_dumper_default*)d;
     int k,err =0;
     int more = 0;
-    double*  buf = NULL;
+    double* buf = NULL;
     size_t size=0;
     long count=0;
 
@@ -649,9 +646,7 @@ static void dump_section(grib_dumper* d,grib_accessor* a,grib_block_of_accessors
         *q='\0';
 
         sprintf(tmp,"%s ( length=%ld, padding=%ld )",upper,(long)s->length,(long)s->padding);
-        /*
-    fprintf(self->dumper.out,"#==============   %-38s   ==============\n",tmp);
-         */
+        /* fprintf(self->dumper.out,"#==============   %-38s   ==============\n",tmp); */
         free(upper);
         self->section_offset=a->offset;
     }
