@@ -411,34 +411,48 @@ static void dump_string_array(grib_dumper* d,grib_accessor* a,const char* commen
     (void)err; /* TODO */
 }
 
+# define MAX_STRING_SIZE 4096
 static void dump_string(grib_dumper* d,grib_accessor* a,const char* comment)
 {
     grib_dumper_json *self = (grib_dumper_json*)d;
-    char *value = NULL;
+    char value[MAX_STRING_SIZE] = {0,};  /* See ECC-710 */
     char *p = NULL;
-    size_t size = 0;
+    size_t size = MAX_STRING_SIZE;
     int is_missing = 0;
-    grib_context* c = NULL;
-    int err = _grib_get_string_length(a,&size);
+    int err = 0;
+    const char* acc_name = a->name;
 
-    c = a->context;
-    if (size==0) return;
-
-    if ( (a->flags & GRIB_ACCESSOR_FLAG_DUMP) == 0)
-        return;
-
-    value=(char*)grib_context_malloc_clear(c,size);
-    if (!value) {
-        grib_context_log(c,GRIB_LOG_FATAL,"unable to allocate %d bytes",(int)size);
-        return;
+    if ( (a->flags & GRIB_ACCESSOR_FLAG_DUMP) == 0) {
+        /* ECC-356: Solution for the special local section key 'keyMore' and its alias 'ident' */
+        int skip = 1;
+        if ( (a->flags & GRIB_ACCESSOR_FLAG_HIDDEN)!=0 ) {
+            grib_handle* h = grib_handle_of_accessor(a);
+            if ( strcmp(a->name, "keyMore")==0 && grib_is_defined(h, "ls.ident") ) {
+                skip = 0;
+                acc_name = "ident";
+            }
+        }
+        if (skip) return;
     }
 
+    /* ECC-710: It is MUCH slower determining the string length here
+     * than using a maximum size (and no need for malloc).
+     * Specially for BUFR elements */
+    /*err = _grib_get_string_length(a,&size);
+    if (size==0) return;
+    value=(char*)grib_context_malloc_clear(a->context,size);
+    if (!value) {
+        grib_context_log(a->context,GRIB_LOG_FATAL,"unable to allocate %d bytes",(int)size);
+        return;
+    }*/
+
     if (self->begin==0 && self->empty==0 && self->isAttribute==0) fprintf(self->dumper.out,",");
     else self->begin=0;
 
     self->empty=0;
 
     err = grib_unpack_string(a,value,&size);
+    Assert(size < MAX_STRING_SIZE);
     p=value;
     if (grib_is_missing_string(a,(unsigned char *)value,size)) {
         is_missing = 1;
@@ -450,7 +464,7 @@ static void dump_string(grib_dumper* d,grib_accessor* a,const char* comment)
         fprintf(self->dumper.out,"\n%-*s{",depth," ");
         depth+=2;
         fprintf(self->dumper.out,"\n%-*s",depth," ");
-        fprintf(self->dumper.out,"\"key\" : \"%s\",",a->name);
+        fprintf(self->dumper.out,"\"key\" : \"%s\",",acc_name);
         fprintf(self->dumper.out,"\n%-*s",depth," ");
         fprintf(self->dumper.out,"\"value\" : ");
     }
@@ -465,7 +479,7 @@ static void dump_string(grib_dumper* d,grib_accessor* a,const char* comment)
         fprintf(self->dumper.out,"\n%-*s}",depth," ");
     }
 
-    grib_context_free(c,value);
+    /*grib_context_free(a->context,value);*/
     (void)err; /* TODO */
 }
 
