@@ -144,6 +144,10 @@ static void dump_long(grib_dumper* d,grib_accessor* a,const char* comment)
     int err = 0, i = 0;
     long count = 0;
 
+    if( a->length == 0  &&
+            (d->option_flags & GRIB_DUMP_FLAG_CODED) != 0)
+        return;
+
     grib_value_count(a,&count);
     size=count;
 
@@ -154,10 +158,6 @@ static void dump_long(grib_dumper* d,grib_accessor* a,const char* comment)
         err=grib_unpack_long(a,&value,&size);
     }
 
-    if( a->length == 0  &&
-            (d->option_flags & GRIB_DUMP_FLAG_CODED) != 0)
-        return;
-
     if( (a->flags & GRIB_ACCESSOR_FLAG_READ_ONLY) != 0 &&
             (d->option_flags & GRIB_DUMP_FLAG_READ_ONLY) == 0)
         return;
@@ -208,12 +208,13 @@ static void dump_bits(grib_dumper* d,grib_accessor* a,const char* comment)
     grib_dumper_wmo *self = (grib_dumper_wmo*)d;
     int i;
     long value = 0; size_t size = 1;
-    int err = grib_unpack_long(a,&value,&size);
+    int err = 0;
 
     if( a->length == 0  &&
             (d->option_flags & GRIB_DUMP_FLAG_CODED) != 0)
         return;
 
+    err = grib_unpack_long(a,&value,&size);
     set_begin_end(d,a);
 
     /*for(i = 0; i < d->depth ; i++) fprintf(self->dumper.out," ");*/
@@ -249,13 +250,13 @@ static void dump_double(grib_dumper* d,grib_accessor* a,const char* comment)
 {
     grib_dumper_wmo *self = (grib_dumper_wmo*)d;
     double value=0; size_t size = 1;
-    int err = grib_unpack_double(a,&value,&size);
-
+    int err = 0;
 
     if( a->length == 0  &&
             (d->option_flags & GRIB_DUMP_FLAG_CODED) != 0)
         return;
 
+    err = grib_unpack_double(a,&value,&size);
     set_begin_end(d,a);
 
     /*for(i = 0; i < d->depth ; i++) fprintf(self->dumper.out," ");*/
@@ -284,8 +285,14 @@ static void dump_string(grib_dumper* d,grib_accessor* a,const char* comment)
     size_t size=0;
     char *value=NULL;
     char *p=NULL;
-    int err = _grib_get_string_length(a,&size);
+    int err = 0;
 
+    if( a->length == 0  &&
+            (d->option_flags & GRIB_DUMP_FLAG_CODED) != 0) {
+        return;
+    }
+
+    err = _grib_get_string_length(a,&size);
     value=(char*)grib_context_malloc_clear(a->context,size);
     if (!value) {
         grib_context_log(a->context,GRIB_LOG_FATAL,"unable to allocate %d bytes",(int)size);
@@ -294,12 +301,6 @@ static void dump_string(grib_dumper* d,grib_accessor* a,const char* comment)
     err=grib_unpack_string(a,value,&size);
     p=value;
 
-    if( a->length == 0  &&
-            (d->option_flags & GRIB_DUMP_FLAG_CODED) != 0) {
-        grib_context_free(a->context,value);
-        return;
-    }
-
     set_begin_end(d,a);
 
     while(*p) { if(!isprint(*p)) *p = '.'; p++; }
