@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2017 ECMWF.
+ * Copyright 2005-2018 ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -29,6 +29,7 @@
    MEMBERS    = double southPoleLat
    MEMBERS    = double southPoleLon
    MEMBERS    = long jPointsAreConsecutive
+   MEMBERS    = long disableUnrotate
    END_CLASS_DEF
 
  */
@@ -62,12 +63,13 @@ typedef struct grib_iterator_regular{
 	double   *los;
 	long      nap;
 	long      nam;
-	long   iScansNegatively;
-	long   isRotated;
+	long iScansNegatively;
+	long isRotated;
 	double angleOfRotation;
 	double southPoleLat;
 	double southPoleLon;
-	long   jPointsAreConsecutive;
+	long jPointsAreConsecutive;
+    long disableUnrotate;
 } grib_iterator_regular;
 
 extern grib_iterator_class* grib_iterator_class_gen;
@@ -97,7 +99,8 @@ static void init_class(grib_iterator_class* c)
 /* END_CLASS_IMP */
 
 
-static int next(grib_iterator* i, double *lat, double *lon, double *val){
+static int next(grib_iterator* i, double *lat, double *lon, double *val)
+{
     grib_iterator_regular* self = (grib_iterator_regular*)i;
 
     if((long)i->e >= (long)(i->nv-1))  return 0;
@@ -111,7 +114,8 @@ static int next(grib_iterator* i, double *lat, double *lon, double *val){
     return 1;
 }
 
-static int previous(grib_iterator* i, double *lat, double *lon, double *val){
+static int previous(grib_iterator* i, double *lat, double *lon, double *val)
+{
     grib_iterator_regular* self = (grib_iterator_regular*)i;
 
     if(i->e < 0)      return 0;
@@ -178,12 +182,11 @@ static int init(grib_iterator* i,grib_handle* h,grib_arguments* args)
     if (self->iScansNegatively) {
         idir=-idir;
     } else {
-        const double epsilon = 1e-6;
         if (lon1+(Ni-2)*idir>360) lon1-=360;
-        else if ( (lon1+(Ni-1)*idir)-360 > epsilon ){
-            /*See GRIB-396*/
+        /*See ECC-704, GRIB-396*/
+        /*else if ( (lon1+(Ni-1)*idir)-360 > epsilon ){
             idir=360.0/(float)Ni;
-        }
+        }*/
     }
 
     self->nap = Ni;
