@@ -186,6 +186,10 @@ static int find(grib_nearest* nearest, grib_handle* h,
                 self->lats[ilat++]=lat;
                 olat=lat;
             }
+            while(lon>360) lon-=360;
+            if(!self->global) {  /* ECC-756 */
+                if (lon>180 && lon<360) lon-=360;
+            }
             self->lons[ilon++]=lon;
         }
         self->lats_count=ilat;
@@ -243,20 +247,24 @@ static int find(grib_nearest* nearest, grib_handle* h,
             nlon=0;
             for (jj=0;jj<self->j[0];jj++) {
                 row_count=0;ilon_first=0;ilon_last=0;
-                grib_get_reduced_row(pl[jj],self->lon_first,self->lon_last,&row_count,&ilon_first,&ilon_last);
+                grib_get_reduced_row_wrapper(h, pl[jj],self->lon_first,self->lon_last,&row_count,&ilon_first,&ilon_last);
                 nlon+=row_count;
             }
             row_count=0;ilon_first=0;ilon_last=0;
-            grib_get_reduced_row(pl[self->j[0]],self->lon_first,self->lon_last,&row_count,&ilon_first,&ilon_last);
+            grib_get_reduced_row_wrapper(h, pl[self->j[0]],self->lon_first,self->lon_last,&row_count,&ilon_first,&ilon_last);
             nplm1=row_count-1;
         }
         lons=self->lons+nlon;
 
         nearest_lons_found=0;
+        /* ECC-756: The comparisons of longitudes here depends on the longitude values
+         * from the point iterator. The old values could be -ve but the new algorithm
+         * generates +ve values which break this test:
+         *    lons[nplm1]>lons[0]
+         */
         if (lons[nplm1]>lons[0]) {
             if (inlon< lons[0] || inlon > lons[nplm1]) {
-                if (lons[nplm1]-lons[0]-360 <=
-                        lons[nplm1]-lons[nplm1-1]) {
+                if (lons[nplm1]-lons[0]-360 <= lons[nplm1]-lons[nplm1-1]) {
                     self->k[0]=0;
                     self->k[1]=nplm1;
                     nearest_lons_found=1;
@@ -264,8 +272,7 @@ static int find(grib_nearest* nearest, grib_handle* h,
             }
         } else {
             if (inlon >lons[0] || inlon< lons[nplm1]) {
-                if (lons[0]-lons[nplm1]-360 <=
-                        lons[0]-lons[1]) {
+                if (lons[0]-lons[nplm1]-360 <= lons[0]-lons[1]) {
                     self->k[0]=0;
                     self->k[1]=nplm1;
                     nearest_lons_found=1;
@@ -276,7 +283,7 @@ static int find(grib_nearest* nearest, grib_handle* h,
         if (!nearest_lons_found) {
             if (!self->global) {
                 row_count=0;ilon_first=0;ilon_last=0;
-                grib_get_reduced_row(pl[self->j[0]],self->lon_first,self->lon_last,&row_count,&ilon_first,&ilon_last);
+                grib_get_reduced_row_wrapper(h, pl[self->j[0]],self->lon_first,self->lon_last,&row_count,&ilon_first,&ilon_last);
             } else {
                 row_count=pl[self->j[0]];
             }
@@ -294,11 +301,11 @@ static int find(grib_nearest* nearest, grib_handle* h,
         } else {
             for (jj=0;jj<self->j[1];jj++) {
                 row_count=0;ilon_first=0;ilon_last=0;
-                grib_get_reduced_row(pl[jj],self->lon_first,self->lon_last,&row_count,&ilon_first,&ilon_last);
+                grib_get_reduced_row_wrapper(h, pl[jj],self->lon_first,self->lon_last,&row_count,&ilon_first,&ilon_last);
                 nlon+=row_count;
             }
             row_count=0;ilon_first=0;ilon_last=0;
-            grib_get_reduced_row(pl[self->j[1]],self->lon_first,self->lon_last,&nplm1,&ilon_first,&ilon_last);
+            grib_get_reduced_row_wrapper(h, pl[self->j[1]],self->lon_first,self->lon_last,&nplm1,&ilon_first,&ilon_last);
             nplm1--;
         }
         lons=self->lons+nlon;
@@ -327,7 +334,7 @@ static int find(grib_nearest* nearest, grib_handle* h,
         if (!nearest_lons_found) {
             if (!self->global) {
                 row_count=0;ilon_first=0;ilon_last=0;
-                grib_get_reduced_row(pl[self->j[1]],self->lon_first,self->lon_last,&row_count,&ilon_first,&ilon_last);
+                grib_get_reduced_row_wrapper(h, pl[self->j[1]],self->lon_first,self->lon_last,&row_count,&ilon_first,&ilon_last);
             } else {
                 row_count=pl[self->j[1]];
             }
