@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2017 ECMWF.
+ * Copyright 2005-2018 ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -134,7 +134,7 @@ static grib_accessor* _search_and_cache(grib_handle* h, const char* name,const c
     }
 }
 
-static char* get_rank(const char* name,int *rank) {
+static char* get_rank(grib_context* c, const char* name,int *rank) {
     char* p=(char*)name;
     char* end=p;
     char* ret=NULL;
@@ -146,7 +146,7 @@ static char* get_rank(const char* name,int *rank) {
         if ( *end != '#') {
             *rank=-1;
         } else {
-            grib_context* c=grib_context_get_default();
+            DebugAssert(c);
             end++;
             ret=grib_context_strdup(c,end);
         }
@@ -235,7 +235,7 @@ static grib_accessor* search_by_rank(grib_handle* h, const char* name,int rank,c
     } else {
         grib_accessor* ret=NULL;
         int rank2;
-        char* str=get_rank(name,&rank2);
+        char* str=get_rank(h->context, name, &rank2);
         ret=_search_and_cache(h,str,the_namespace);
         grib_context_free(h->context,str);
         return ret;
@@ -372,7 +372,7 @@ grib_accessors_list* grib_find_accessors_list(grib_handle* h,const char* name)
             char* str2;
             int r;
             al=(grib_accessors_list*)grib_context_malloc_clear(h->context,sizeof(grib_accessors_list));
-            str2=get_rank(name,&r);
+            str2=get_rank(h->context, name, &r);
             grib_accessors_list_push(al,a,r);
             grib_context_free(h->context,str2);
         }
@@ -393,7 +393,7 @@ static grib_accessor* search_and_cache(grib_handle* h, const char* name,const ch
 
     if (name[0]=='#') {
         int rank=-1;
-        char* basename=get_rank(name,&rank);
+        char* basename=get_rank(h->context, name, &rank);
         a=search_by_rank(h,basename,rank,the_namespace);
         grib_context_free(h->context,basename);
     } else {
@@ -409,7 +409,7 @@ static grib_accessor* _grib_find_accessor(grib_handle* h, const char* name)
     char* p = NULL;
     DebugAssert(name);
 
-    p = strchr(name, '.');
+    p = strchr((char*)name, '.');
     if ( p ) {
         int i=0,len=0;
         char name_space[MAX_NAMESPACE_LEN];
@@ -439,7 +439,7 @@ char* grib_split_name_attribute(grib_context* c,const char* name,char* attribute
     /*returns accessor name and attribute*/
     size_t size=0;
     char* accessor_name=NULL;
-    char* p = strstr(name, "->");
+    char* p = strstr((char*)name, "->");
     if (!p) {
         *attribute_name=0;
         return (char*)name;
@@ -455,7 +455,7 @@ char* grib_split_name_attribute(grib_context* c,const char* name,char* attribute
 grib_accessor* grib_find_accessor(grib_handle* h, const char* name)
 {
     grib_accessor* aret = NULL;
-
+    Assert(h);
     if (h->product_kind == PRODUCT_GRIB) {
         aret = _grib_find_accessor(h, name); /* ECC-144: Performance */
     }
@@ -502,7 +502,7 @@ grib_accessor* grib_find_accessor_fast(grib_handle* h, const char* name)
     char* p = NULL;
     DebugAssert(name);
 
-    p = strchr(name, '.');
+    p = strchr((char*)name, '.');
     if ( p ) {
         int i=0,len=0;
         char name_space[MAX_NAMESPACE_LEN];
