@@ -12,17 +12,10 @@
  */
 
 #include <stdlib.h>
-#include "eccodes_windef.h"
-
-#ifdef ECCODES_ON_WINDOWS
-	typedef unsigned __int64 UnsignedInt64;
-#else
-#   include <stdint.h>
-	typedef uint64_t          UnsignedInt64;
-#endif
+#include <stdint.h>
 
 typedef struct grib_md5_state {
-	UnsignedInt64  size;
+	uint64_t size;
 
 	unsigned long words[64];
 	unsigned long word_count;
