@@ -1,5 +1,5 @@
 #!/bin/sh
-# Copyright 2005-2017 ECMWF.
+# Copyright 2005-2018 ECMWF.
 #
 # This software is licensed under the terms of the Apache Licence Version 2.0
 # which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -35,7 +35,7 @@ fRules=${label}.filter
 f="syno_1.bufr"
 echo "Test: comparing the same files" >> $fLog
 echo "file: $f" >> $fLog
-${tools_dir}//bufr_compare $f $f >> $fLog
+${tools_dir}/bufr_compare $f $f >> $fLog
 
 #----------------------------------------------------
 # Test: comparing two completely different files
@@ -45,7 +45,7 @@ f1="syno_1.bufr"
 f2="aaen_55.bufr"
 echo "Test: comparing two completely different files" >> $fLog
 echo "file: $f" >> $fLog
-${tools_dir}//bufr_compare $f1 $f2 >> $fLog
+${tools_dir}/bufr_compare $f1 $f2 >> $fLog
 if [ $? -eq 0 ]; then
    echo "bufr_compare should have failed if files are completely different" >&2
    exit 1
@@ -60,10 +60,10 @@ echo "Test: comparing with and witout the -b switch" >> $fLog
 echo "file: $f" >> $fLog
 
 #Alter a key in the file 
-${tools_dir}//bufr_set -s dataCategory=2 $f ${fBufrTmp} >> $fLog
+${tools_dir}/bufr_set -s dataCategory=2 $f ${fBufrTmp} >> $fLog
 
 set +e
-${tools_dir}//bufr_compare $f ${fBufrTmp}>> $fLog
+${tools_dir}/bufr_compare $f ${fBufrTmp}>> $fLog
 if [ $? -eq 0 ]; then
    echo "bufr_compare should have failed if files are different" >&2
    exit 1
@@ -71,7 +71,7 @@ fi
 set -e
 
 # Now compare with -b switch. No difference should be found.
-${tools_dir}//bufr_compare -b dataCategory $f ${fBufrTmp}>> $fLog
+${tools_dir}/bufr_compare -b dataCategory $f ${fBufrTmp}>> $fLog
 
 #----------------------------------------------------
 # Test: comparing with the -r switch
@@ -81,13 +81,13 @@ ${tools_dir}//bufr_compare -b dataCategory $f ${fBufrTmp}>> $fLog
 #cat temp_101.bufr syno_multi.bufr > $fBufrInput2
 
 #set +e
-#${tools_dir}//bufr_compare ${fBufrInput1} ${fBufrInput2} >> $fLog
+#${tools_dir}/bufr_compare ${fBufrInput1} ${fBufrInput2} >> $fLog
 #if [ $? -eq 0 ]; then
 #   echo "bufr_compare should have failed if the message order in the files is different" >&2
 #   exit 1
 #fi
 #set -e
-#${tools_dir}//bufr_compare -r ${fBufrInput1} ${fBufrInput2}>> $fLog
+#${tools_dir}/bufr_compare -r ${fBufrInput1} ${fBufrInput2}>> $fLog
 
 #----------------------------------------------------
 # Change subCentre and compare
@@ -138,5 +138,48 @@ ${tools_dir}/codes_bufr_filter -o $fBufrTmp $fRules $f
 # Header keys have not changed
 ${tools_dir}/bufr_compare -H $f $fBufrTmp
 
-#Clean up
+#----------------------------------------------------
+# Compare two-way (symmetric mode)
+#----------------------------------------------------
+f=$ECCODES_SAMPLES_PATH/BUFR3.tmpl
+# Add a local section
+${tools_dir}/bufr_set -s section2Present=1 $f $fBufrTmp
+# Compare A with B will pass
+${tools_dir}/bufr_compare $f $fBufrTmp
+# Compare with -2 option
+set +e
+${tools_dir}/bufr_compare -2 $f $fBufrTmp > $fLog 2>&1
+status=$?
+set -e
+[ $status -eq 1 ]
+
+#----------------------------------------------------
+# ECC-656: using relative comparison (-R) with 'all'
+#----------------------------------------------------
+f='airc_142.bufr'
+echo 'set unpack=1;set airTemperature=228; set height=1.037e+04; set pack=1; write;' |\
+    ${tools_dir}/codes_bufr_filter -o $fBufrTmp - $f
+${tools_dir}/bufr_compare -R airTemperature=0.004,height=0.001 $f $fBufrTmp
+${tools_dir}/bufr_compare -R all=0.004 $f $fBufrTmp
+
+#----------------------------------------------------
+# ECC-658: apply relative comparison (-R) to all
+# ranks of a given key
+#----------------------------------------------------
+f='PraticaTemp.bufr'
+${tools_dir}/codes_bufr_filter -o $fBufrTmp - $f <<EOF
+ set unpack=1;
+ set #1#airTemperature=288.41;
+ set #2#airTemperature=286.15;
+ set #3#airTemperature=280.95;
+ set #4#airTemperature=280.32;
+ set #5#airTemperature=280.43;
+ set pack=1;
+ write;
+EOF
+# The relative differences are around 3.5e-5. Suppress all instances
+${tools_dir}/bufr_compare -R airTemperature=4e-5 $f $fBufrTmp
+
+# Clean up
+# -------------
 rm -f $fLog $fBufrTmp $fBufrInput1 $fBufrInput2 $fRules
