@@ -1,5 +1,5 @@
 #!/bin/sh
-# Copyright 2005-2017 ECMWF.
+# Copyright 2005-2018 ECMWF.
 #
 # This software is licensed under the terms of the Apache Licence Version 2.0
 # which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -32,6 +32,7 @@ fRules=${label}.filter
 #-----------------------------------------------------------
 cat > $fRules <<EOF
  transient originalNumberOfSubsets = numberOfSubsets;
+ set unpack=1;
  set extractAreaNorthLatitude=52.5;
  set extractAreaSouthLatitude=51.1;
  set extractAreaWestLongitude=155.2;
@@ -136,4 +137,26 @@ EOF
 
 diff $outputRef $outputFilt
 
+# Uncompressed message
+# ---------------------
+inputBufr="delayed_repl_01.bufr"
+outputBufr=${label}.${inputBufr}.out
+cat > $fRules <<EOF
+ transient originalNumberOfSubsets = numberOfSubsets;
+ set unpack=1;
+ set extractAreaNorthLatitude = -21.0;
+ set extractAreaSouthLatitude = -25.0;
+ set extractAreaWestLongitude = 136;
+ set extractAreaEastLongitude = 154;
+ set extractAreaLongitudeRank=1;
+ set doExtractArea=1;
+ write;
+ print "extracted [numberOfSubsets] of [originalNumberOfSubsets] subsets";
+ assert(3 == extractedAreaNumberOfSubsets);
+EOF
+
+${tools_dir}/codes_bufr_filter -o $outputBufr $fRules $inputBufr
+ns=`${tools_dir}/bufr_get -p numberOfSubsets $outputBufr`
+[ $ns -eq 3 ]
+
 rm -f $outputRef $outputFilt $outputBufr $fLog $fRules
