@@ -1,5 +1,5 @@
 #!/bin/sh
-# Copyright 2005-2017 ECMWF.
+# Copyright 2005-2018 ECMWF.
 #
 # This software is licensed under the terms of the Apache Licence Version 2.0
 # which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -32,6 +32,7 @@ fRules=${label}.filter
 #-----------------------------------------------------------
 cat > $fRules <<EOF
  transient originalNumberOfSubsets = numberOfSubsets;
+ set unpack=1;
 
  transient extractDateTimeYearStart=2012;
  transient extractDateTimeMonthStart=10;
@@ -127,6 +128,7 @@ diff $outputRef $outputFilt
 #-----------------------------------------------------------
 cat > $fRules <<EOF
  transient originalNumberOfSubsets=numberOfSubsets;
+ set unpack=1;
  transient extractDateTimeYearStart=2012;
  transient extractDateTimeMonthStart=19; # Bad month
  transient extractDateTimeDayStart=31;
@@ -161,6 +163,7 @@ fi
 #-----------------------------------------------------------
 cat > $fRules <<EOF
  transient originalNumberOfSubsets=numberOfSubsets;
+ set unpack=1;
  transient extractDateTimeYearStart=2012;
  transient extractDateTimeMonthStart=10;
  transient extractDateTimeDayStart=31;
@@ -190,6 +193,33 @@ if [ $status -eq 0 ]; then
    exit 1
 fi
 
+#-----------------------------------------------------------
+# Test boundary case
+#-----------------------------------------------------------
+cat > $fRules <<EOF
+ transient originalNumberOfSubsets=numberOfSubsets;
+ set unpack=1;
+ transient extractDateTimeYearStart  =2012;
+ transient extractDateTimeMonthStart =10;
+ transient extractDateTimeDayStart   =31;
+ transient extractDateTimeHourStart  =0;
+ transient extractDateTimeMinuteStart=1;
+ transient extractDateTimeSecondStart=24;
+
+ transient extractDateTimeYearEnd    =2012;
+ transient extractDateTimeMonthEnd   =10;
+ transient extractDateTimeDayEnd     =31;
+ transient extractDateTimeHourEnd    =0;
+ transient extractDateTimeMinuteEnd  =1;
+ transient extractDateTimeSecondEnd  =31;#25;
+
+ set doExtractDateTime=1;
+ print "extracted [extractedDateTimeNumberOfSubsets] of [originalNumberOfSubsets] subsets";
+ assert(extractedDateTimeNumberOfSubsets==0);
+EOF
+inputBufr="amsa_55.bufr"
+outputBufr=${label}.${inputBufr}.out
+${tools_dir}/codes_bufr_filter -o $outputBufr $fRules $inputBufr
 
 
 rm -f $outputRef $outputFilt $outputBufr $fLog $fRules
