@@ -25,11 +25,11 @@ outfile1=$infile.tmp_ccsds.1
 outfile2=$infile.tmp_ccsds.2
 
 rm -f $outfile1 $outfile2
-${tools_dir}/grib_set -f -r -s packingType=grid_simple $infile $outfile1
-${tools_dir}/grib_compare -P -b $BLACKLIST $outfile1 $infile > $REDIRECT
+${tools_dir}/grib_set -r -s packingType=grid_simple $infile $outfile1
+${tools_dir}/grib_compare -b $BLACKLIST $outfile1 $infile > $REDIRECT
 
 ${tools_dir}/grib_set -r -s packingType=grid_ccsds $outfile1 $outfile2
-${tools_dir}/grib_compare -P -b $BLACKLIST $outfile1 $outfile2 > $REDIRECT
+${tools_dir}/grib_compare -b $BLACKLIST $outfile1 $outfile2 > $REDIRECT
 
 templateNumber=`${tools_dir}/grib_get -p dataRepresentationTemplateNumber $outfile2`
 
@@ -46,9 +46,9 @@ outfile1=$infile.tmp_ccsds.1
 outfile2=$infile.tmp_ccsds.2
 
 ${tools_dir}/grib_set -r -s packingType=grid_ccsds $infile $outfile1
-${tools_dir}/grib_compare -P -b $BLACKLIST $infile $outfile1 > $REDIRECT
-${tools_dir}/grib_set -f -r -s packingType=grid_simple $outfile1 $outfile2
-${tools_dir}/grib_compare -P -b $BLACKLIST $outfile2 $outfile1  > $REDIRECT
+${tools_dir}/grib_compare -b $BLACKLIST $infile $outfile1 > $REDIRECT
+${tools_dir}/grib_set -r -s packingType=grid_simple $outfile1 $outfile2
+${tools_dir}/grib_compare -b $BLACKLIST $outfile2 $outfile1  > $REDIRECT
 
 res1=`${tools_dir}/grib_get '-F%1.2f' -p min,max,avg $infile`
 res2=`${tools_dir}/grib_get '-F%1.2f' -p min,max,avg $outfile1`
@@ -65,12 +65,12 @@ outfile2=$infile.tmp_ccsds.2
 
 ${tools_dir}/grib_set -r -s bitsPerValue=17 $infile $outfile1
 ${tools_dir}/grib_set -r -s packingType=grid_ccsds $outfile1 $outfile2
-${tools_dir}/grib_compare -P -c data:n $outfile1 $outfile2
+${tools_dir}/grib_compare -c data:n $outfile1 $outfile2
 
 # ECC-477: redundant error message during conversion
 infile=${data_dir}/ccsds.grib2
 rm -f $outfile2
-${tools_dir}/grib_set -f -r -s packingType=grid_simple $infile $outfile1 >$outfile2 2>&1
+${tools_dir}/grib_set -r -s packingType=grid_simple $infile $outfile1 >$outfile2 2>&1
 # there should be no error messages printed (to stdout or stderr)
 [ ! -s $outfile2 ]
 
