@@ -1,5 +1,5 @@
 #!/bin/sh
-# Copyright 2005-2017 ECMWF.
+# Copyright 2005-2018 ECMWF.
 #
 # This software is licensed under the terms of the Apache Licence Version 2.0
 # which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -22,4 +22,4 @@ infile=${data_dir}/grid_ieee.grib
 #   exit 1
 # fi
 
-${test_dir}/grib_double_cmp ${infile}
+$EXEC ${test_dir}/grib_double_cmp ${infile}
