@@ -1,5 +1,5 @@
 #!/bin/sh
-# Copyright 2005-2017 ECMWF.
+# Copyright 2005-2018 ECMWF.
 #
 # This software is licensed under the terms of the Apache Licence Version 2.0
 # which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -10,9 +10,8 @@
 
 
 . ./include.sh
-${test_dir}/julian > ${data_dir}/julian.out
+$EXEC ${test_dir}/julian > ${data_dir}/julian.out
 
 diff ${data_dir}/julian.out ${data_dir}/julian.out.good
 
 rm -f ${data_dir}/julian.out
-
