@@ -9,14 +9,11 @@
  */
 
 #include "config.h"
-/* #include <sys/types.h> */
-/* #include <inttypes.h> */
-/* #include <stdio.h> */
-/* #include <stdlib.h> */
-/* #include <errno.h> */
-/* #include <string.h> */
 #include "grib_api_internal.h"
+
+#ifndef ECCODES_ON_WINDOWS
 #include <unistd.h>
+#endif
 
 void usage(char* prog) {
   printf("usage: %s filename\n",prog);
