@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2017 ECMWF.
+ * Copyright 2005-2018 ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -15,7 +15,10 @@
 #include "grib_api.h"
 #include <sys/types.h>
 #include <sys/stat.h>
+
+#ifndef ECCODES_ON_WINDOWS
 #include <unistd.h>
+#endif
 
 static void usage(const char* prog) {
     printf("usage: %s [-m] file.grib\n",prog);
