@@ -1408,11 +1408,12 @@ static void my_assertion_proc(const char* message)
 
 static void test_assertion_catching()
 {
+    char empty[]="";
     assert(assertion_caught == 0);
     codes_set_codes_assertion_failed_proc(&my_assertion_proc);
 
     /* Do something illegal */
-    string_split("", " ");
+    string_split(empty, " ");
 
     assert(assertion_caught == 1);
 
