@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2017 ECMWF.
+ * Copyright 2005-2018 ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -25,9 +25,15 @@
 #include <string.h>
 #include <math.h>
 #include <sys/types.h>
-#include <dirent.h>
+#include "tigge_tools.h"
+
+#ifndef ECCODES_ON_WINDOWS
+  #include <dirent.h>
+#else
+  #include <direct.h>
+  #include <io.h>
+#endif
 
-#define CHECK(a) check(#a,a)
 #define NUMBER(a) (sizeof(a)/sizeof(a[0]))
 
 int error = 0;
@@ -37,15 +43,7 @@ const char* param = "unknown";
 int list_mode = 0;
 int compare_mode = 0;
 
-void check(const char* name,int a)
-{
-    if(!a) {
-        printf("%s, field %d [%s]: %s failed\n",file,field,param,name);
-        error++;
-    }
-}
-
-long get(grib_handle *h,const char* what)
+static long get(grib_handle *h,const char* what)
 {
     int e; long val;
     if((e = grib_get_long(h,what,&val)) != GRIB_SUCCESS)
@@ -57,7 +55,7 @@ long get(grib_handle *h,const char* what)
     return val;
 }
 
-char* sget(grib_handle *h,const char* what,char* val,size_t size)
+static char* sget(grib_handle *h,const char* what,char* val,size_t size)
 {
     int e; 
     if((e = grib_get_string(h,what,val,&size)) != GRIB_SUCCESS)
@@ -68,41 +66,7 @@ char* sget(grib_handle *h,const char* what,char* val,size_t size)
     return val;
 }
 
-
-double dget(grib_handle *h,const char* what)
-{
-    int e; double val;
-    if((e = grib_get_double(h,what,&val)) != GRIB_SUCCESS)
-    {
-        printf("%s, field %d [%s]: cannot get %s: %s\n",file,field,param,what,grib_get_error_message(e));
-        error++;
-        val = -1;
-    }
-    return val;
-}
-
-int missing(grib_handle *h,const char* what)
-{
-    int err=0;
-    return grib_is_missing(h,what,&err);
-}
-
-int eq(grib_handle *h,const char* what,long value)
-{
-    return get(h,what) == value;
-}
-
-int ne(grib_handle *h,const char* what,long value)
-{
-    return get(h,what) != value;
-}
-
-int ge(grib_handle *h,const char* what,long value)
-{
-    return get(h,what) >= value;
-}
-
-void verify(grib_handle *h,const char* full,const char* base)
+static void verify(grib_handle *h,const char* full,const char* base)
 {
     char wmo_name[1024];
     char origin[80];
@@ -198,32 +162,12 @@ void validate(const char* path)
     }
 }
 
-void usage()
+static void usage()
 {
     printf("tigge_name [-l] [-c] files ....\n");
     exit(1);
 }
 
-void scan(const char* name)
-{
-    DIR *dir;
-    if((dir = opendir(name)) != NULL)
-    {
-        struct dirent* e;
-        char tmp[1024];
-        while( (e = readdir(dir)) != NULL)
-        {
-            if(e->d_name[0] == '.') continue;
-            sprintf(tmp,"%s/%s",name,e->d_name);
-            scan(tmp);
-        }
-
-        closedir(dir);
-    }
-    else
-        validate(name);
-}
-
 int main(int argc, char** argv)
 {
     int i = 1;
