@@ -627,18 +627,18 @@ static char* double_as_string(grib_context* c, double v)
 static char* get_keyname_without_rank(const char* name)
 {
     char* p=(char*)name;
-    char* end=p;
+    char* pEnd=p;
     char* ret=NULL;
 
     if (*p=='#') {
-        strtol(++p,&end,10);
-        if ( *end != '#') {
+        strtol(++p,&pEnd,10);
+        if ( *pEnd != '#') {
             DebugAssert(!"Badly formed rank in key");
         } else {
             /* Take everything after 2nd '#' */
             grib_context* c=grib_context_get_default();
-            end++;
-            ret=grib_context_strdup(c,end);
+            pEnd++;
+            ret=grib_context_strdup(c,pEnd);
         }
     }
     return ret;
