@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2017 ECMWF.
+ * Copyright 2005-2018 ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -15,9 +15,9 @@
 
 #include "grib_tools.h"
 
-char* grib_tool_description="Build an index file for a set of input BUFR files.";
-char* grib_tool_name="bufr_index_build";
-char* grib_tool_usage="[options] file file ... ";
+const char* grib_tool_description="Build an index file for a set of input BUFR files.";
+const char* grib_tool_name="bufr_index_build";
+const char* grib_tool_usage="[options] file file ... ";
 grib_index* idx=NULL;
 char* keys;
 char* default_keys = "mars";
