@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2017 ECMWF.
+ * Copyright 2005-2018 ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -37,11 +37,11 @@ grib_option grib_options[]={
         {"v",0,0,1,0,0}
 };
 
-char* grib_tool_description="List content of BUFR files printing values of "
+const char* grib_tool_description="List content of BUFR files printing values of "
         "some header keys.\n\tOnly scalar keys can be printed."
         "\n\tIt does not fail when a key is not found.";
-char* grib_tool_name="bufr_ls";
-char* grib_tool_usage="[options] bufr_file bufr_file ...";
+const char* grib_tool_name="bufr_ls";
+const char* grib_tool_usage="[options] bufr_file bufr_file ...";
 
 int grib_options_count=sizeof(grib_options)/sizeof(grib_option);
 
@@ -82,14 +82,7 @@ int grib_tool_new_filename_action(grib_runtime_options* options,const char* file
 
 int grib_tool_new_file_action(grib_runtime_options* options,grib_tools_file* file)
 {
-    struct stat s;
-    int stat_val = stat(file->name, &s);
-    if ( stat_val == 0 ) {
-        if (S_ISDIR(s.st_mode)) {
-            fprintf(stderr, "ERROR: \"%s\": Is a directory\n", file->name);
-            exit(1);
-        }
-    }
+    exit_if_input_is_directory(grib_tool_name, file->name);
     return 0;
 }
 
