@@ -32,7 +32,7 @@ int DBL_EQUAL(double d1, double d2, double tolerance)
     return fabs(d1-d2) <= tolerance;
 }
 
-void usage(const char* prog)
+static void usage(const char* prog)
 {
     printf("Usage: %s [-f] [-v] grib_file grib_file ...\n\n",prog);
     printf("Check geometry of GRIB fields with a Gaussian Grid.\n");
