@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2017 ECMWF.
+ * Copyright 2005-2018 ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -15,10 +15,11 @@
 
 #include "grib_tools.h"
 
-char* grib_tool_description="Copies the content of grib files printing"
-        " values of some keys.";
-char* grib_tool_name="grib_copy";
-char* grib_tool_usage="[options] grib_file grib_file ... output_grib_file";
+const char* grib_tool_description="Copies the content of GRIB files printing"
+        " values of some keys."
+        "\n\tIf the name of the output_grib_file contains a key enclosed in square brackets, its value will be used.";
+const char* grib_tool_name="grib_copy";
+const char* grib_tool_usage="[options] grib_file grib_file ... output_grib_file";
 
 grib_option grib_options[]={
         /*  {id, args, help}, on, command_line, value */
@@ -29,7 +30,7 @@ grib_option grib_options[]={
         {"p:",0,0,1,1,0},
         {"P:",0,0,0,1,0},
         {"w:","key[:{s|d|i}]{=|!=}value,key[:{s|d|i}]=value,...","\n\t\tWhere clause."
-             "\n\t\tOnly grib messages matching the key/value constraints are copied to the output_grib_file."
+             "\n\t\tOnly GRIB messages matching the key/value constraints are copied to the output_grib_file."
              "\n\t\tA valid constraint is of type key=value or key!=value."
              "\n\t\tFor each key a string (key:s), a "
              "double (key:d) or an integer (key:i)\n\t\ttype can be defined. Default type is string."
@@ -47,6 +48,7 @@ grib_option grib_options[]={
         {"g",0,0,0,1,0},
         {"G",0,0,0,1,0},
         {"7",0,0,0,1,0},
+        {"X:",0,0,0,1,0},
         {"v",0,0,0,1,0}
 };
 
@@ -74,6 +76,12 @@ int grib_tool_init(grib_runtime_options* options)
         }
     }
 #endif
+    /* ECC-657: If user supplied -p to print some keys, turn on verbose */
+    if (grib_options_on("p:")) {
+        if (grib_options_get_option("p:")) {
+            options->verbose = 1;
+        }
+    }
     return 0;
 }
 
@@ -84,6 +92,7 @@ int grib_tool_new_filename_action(grib_runtime_options* options,const char* file
 
 int grib_tool_new_file_action(grib_runtime_options* options,grib_tools_file* file)
 {
+    exit_if_input_is_directory(grib_tool_name, file->name);
     return 0;
 }
 
