@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2017 ECMWF.
+ * Copyright 2005-2018 ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -26,11 +26,11 @@ grib_option grib_options[]={
     {"7",0,0,0,1,0},
     {"v",0,0,0,1,0}
 };
-char* grib_tool_description="Apply the rules defined in rules_file to each GRIB "
+const char* grib_tool_description="Apply the rules defined in rules_file to each GRIB "
    "message\n\tin the GRIB files provided as arguments.\n\t"
    "If you specify '-' (a single dash) for the rules_file, the rules will be read from standard input.";
-char* grib_tool_name="grib_filter";
-char* grib_tool_usage="[options] rules_file "
+const char* grib_tool_name="grib_filter";
+const char* grib_tool_usage="[options] rules_file "
         "grib_file grib_file ...";
 
 int grib_options_count=sizeof(grib_options)/sizeof(grib_option);
@@ -66,14 +66,7 @@ int grib_tool_new_filename_action(grib_runtime_options* options,const char* file
 
 int grib_tool_new_file_action(grib_runtime_options* options,grib_tools_file* file)
 {
-    struct stat s;
-    int stat_val = stat(file->name, &s);
-    if ( stat_val == 0 ) {
-        if (S_ISDIR(s.st_mode)) {
-            fprintf(stderr, "ERROR: \"%s\": Is a directory\n", file->name);
-            exit(1);
-        }
-    }
+    exit_if_input_is_directory(grib_tool_name, file->name);
     return 0;
 }
 
