@@ -42,10 +42,10 @@ grib_option grib_options[]={
     {"x",0,0,0,1,0}
 };
 
-char* grib_tool_description="List content of GRIB files printing values of "
+const char* grib_tool_description="List content of GRIB files printing values of "
         "some keys.\n\tIt does not fail when a key is not found.";
-char* grib_tool_name="grib_ls";
-char* grib_tool_usage="[options] grib_file grib_file ...";
+const char* grib_tool_name="grib_ls";
+const char* grib_tool_usage="[options] grib_file grib_file ...";
 static char* new_handle="";
 
 int grib_options_count=sizeof(grib_options)/sizeof(grib_option);
@@ -193,14 +193,7 @@ int grib_tool_new_filename_action(grib_runtime_options* options,const char* file
 
 int grib_tool_new_file_action(grib_runtime_options* options,grib_tools_file* file)
 {
-    struct stat s;
-    int stat_val = stat(file->name, &s);
-    if ( stat_val == 0 ) {
-        if (S_ISDIR(s.st_mode)) {
-            fprintf(stderr, "ERROR: \"%s\": Is a directory\n", file->name);
-            exit(1);
-        }
-    }
+    exit_if_input_is_directory(grib_tool_name, file->name);
     return 0;
 }
 
