@@ -45,11 +45,11 @@ grib_option grib_options[]={
         {"v",0,0,0,1,0}
 };
 
-char* grib_tool_description="Sets key/value pairs in the input GRIB file and writes"
+const char* grib_tool_description="Sets key/value pairs in the input GRIB file and writes"
         "\n\teach message to the output_grib_file."
         "\n\tIt fails when an error occurs (e.g. key not found).";
-char* grib_tool_name="grib_set";
-char* grib_tool_usage="[options] grib_file grib_file ... output_grib_file";
+const char* grib_tool_name="grib_set";
+const char* grib_tool_usage="[options] grib_file grib_file ... output_grib_file";
 
 int grib_options_count=sizeof(grib_options)/sizeof(grib_option);
 
