@@ -26,11 +26,11 @@ grib_option grib_options[]={
     {"7",0,0,0,1,0},
     {"v",0,0,0,1,0}
 };
-char* grib_tool_description="Apply the rules defined in rules_file to each GTS "
+const char* grib_tool_description="Apply the rules defined in rules_file to each GTS "
    "message\n\tin the GTS files provided as arguments.\n\t"
         "If you specify '-' (a single dash) for the rules_file, the rules will be read from standard input.";
-char* grib_tool_name="gts_filter";
-char* grib_tool_usage="[options] rules_file "
+const char* grib_tool_name="gts_filter";
+const char* grib_tool_usage="[options] rules_file "
                       "file file ...";
 int fail=0;
 int grib_options_count=sizeof(grib_options)/sizeof(grib_option);
