@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2017 ECMWF.
+ * Copyright 2005-2018 ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -10,10 +10,10 @@
 
 #include "grib_tools.h"
 
-char* grib_tool_description="Copies the content of METAR files printing"
+const char* grib_tool_description="Copies the content of METAR files printing"
         " values of some keys.";
-char* grib_tool_name="metar_copy";
-char* grib_tool_usage="[options] file file ... output_file";
+const char* grib_tool_name="metar_copy";
+const char* grib_tool_usage="[options] file file ... output_file";
 
 grib_option grib_options[]={
         /*  {id, args, help}, on, command_line, value */
